//
// Copyright (C) 2006, NinjaTrader LLC <ninjatrader@ninjatrader.com>.
// NinjaTrader reserves the right to modify or overwrite this NinjaScript component with each release.
//

#region Using declarations
using System;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private Paintbar[] cachePaintbar = null;
        private ttVol[] cachettVol = null;
        private ttVolMA[] cachettVolMA = null;

        private static Paintbar checkPaintbar = new Paintbar();
        private static ttVol checkttVol = new ttVol();
        private static ttVolMA checkttVolMA = new ttVolMA();

        /// <summary>
        /// Paints bars with a specified color for a specified time interval
        /// </summary>
        /// <returns></returns>
        public Paintbar Paintbar(string time1, string time2)
        {
            return Paintbar(Input, time1, time2);
        }

        /// <summary>
        /// Paints bars with a specified color for a specified time interval
        /// </summary>
        /// <returns></returns>
        public Paintbar Paintbar(Data.IDataSeries input, string time1, string time2)
        {
            if (cachePaintbar != null)
                for (int idx = 0; idx < cachePaintbar.Length; idx++)
                    if (cachePaintbar[idx].Time1 == time1 && cachePaintbar[idx].Time2 == time2 && cachePaintbar[idx].EqualsInput(input))
                        return cachePaintbar[idx];

            lock (checkPaintbar)
            {
                checkPaintbar.Time1 = time1;
                time1 = checkPaintbar.Time1;
                checkPaintbar.Time2 = time2;
                time2 = checkPaintbar.Time2;

                if (cachePaintbar != null)
                    for (int idx = 0; idx < cachePaintbar.Length; idx++)
                        if (cachePaintbar[idx].Time1 == time1 && cachePaintbar[idx].Time2 == time2 && cachePaintbar[idx].EqualsInput(input))
                            return cachePaintbar[idx];

                Paintbar indicator = new Paintbar();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.Time1 = time1;
                indicator.Time2 = time2;
                Indicators.Add(indicator);
                indicator.SetUp();

                Paintbar[] tmp = new Paintbar[cachePaintbar == null ? 1 : cachePaintbar.Length + 1];
                if (cachePaintbar != null)
                    cachePaintbar.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cachePaintbar = tmp;
                return indicator;
            }
        }

        /// <summary>
        /// Volume traded during the specific time frame.
        /// </summary>
        /// <returns></returns>
        public ttVol ttVol()
        {
            return ttVol(Input);
        }

        /// <summary>
        /// Volume traded during the specific time frame.
        /// </summary>
        /// <returns></returns>
        public ttVol ttVol(Data.IDataSeries input)
        {
            if (cachettVol != null)
                for (int idx = 0; idx < cachettVol.Length; idx++)
                    if (cachettVol[idx].EqualsInput(input))
                        return cachettVol[idx];

            lock (checkttVol)
            {
                if (cachettVol != null)
                    for (int idx = 0; idx < cachettVol.Length; idx++)
                        if (cachettVol[idx].EqualsInput(input))
                            return cachettVol[idx];

                ttVol indicator = new ttVol();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                ttVol[] tmp = new ttVol[cachettVol == null ? 1 : cachettVol.Length + 1];
                if (cachettVol != null)
                    cachettVol.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cachettVol = tmp;
                return indicator;
            }
        }

        /// <summary>
        /// The ttVolMA (Volume Moving Average) plots a simple moving average (SMA) of volume.
        /// </summary>
        /// <returns></returns>
        public ttVolMA ttVolMA(int period)
        {
            return ttVolMA(Input, period);
        }

        /// <summary>
        /// The ttVolMA (Volume Moving Average) plots a simple moving average (SMA) of volume.
        /// </summary>
        /// <returns></returns>
        public ttVolMA ttVolMA(Data.IDataSeries input, int period)
        {
            if (cachettVolMA != null)
                for (int idx = 0; idx < cachettVolMA.Length; idx++)
                    if (cachettVolMA[idx].Period == period && cachettVolMA[idx].EqualsInput(input))
                        return cachettVolMA[idx];

            lock (checkttVolMA)
            {
                checkttVolMA.Period = period;
                period = checkttVolMA.Period;

                if (cachettVolMA != null)
                    for (int idx = 0; idx < cachettVolMA.Length; idx++)
                        if (cachettVolMA[idx].Period == period && cachettVolMA[idx].EqualsInput(input))
                            return cachettVolMA[idx];

                ttVolMA indicator = new ttVolMA();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.Period = period;
                Indicators.Add(indicator);
                indicator.SetUp();

                ttVolMA[] tmp = new ttVolMA[cachettVolMA == null ? 1 : cachettVolMA.Length + 1];
                if (cachettVolMA != null)
                    cachettVolMA.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cachettVolMA = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Paints bars with a specified color for a specified time interval
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.Paintbar Paintbar(string time1, string time2)
        {
            return _indicator.Paintbar(Input, time1, time2);
        }

        /// <summary>
        /// Paints bars with a specified color for a specified time interval
        /// </summary>
        /// <returns></returns>
        public Indicator.Paintbar Paintbar(Data.IDataSeries input, string time1, string time2)
        {
            return _indicator.Paintbar(input, time1, time2);
        }

        /// <summary>
        /// Volume traded during the specific time frame.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ttVol ttVol()
        {
            return _indicator.ttVol(Input);
        }

        /// <summary>
        /// Volume traded during the specific time frame.
        /// </summary>
        /// <returns></returns>
        public Indicator.ttVol ttVol(Data.IDataSeries input)
        {
            return _indicator.ttVol(input);
        }

        /// <summary>
        /// The ttVolMA (Volume Moving Average) plots a simple moving average (SMA) of volume.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ttVolMA ttVolMA(int period)
        {
            return _indicator.ttVolMA(Input, period);
        }

        /// <summary>
        /// The ttVolMA (Volume Moving Average) plots a simple moving average (SMA) of volume.
        /// </summary>
        /// <returns></returns>
        public Indicator.ttVolMA ttVolMA(Data.IDataSeries input, int period)
        {
            return _indicator.ttVolMA(input, period);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Paints bars with a specified color for a specified time interval
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.Paintbar Paintbar(string time1, string time2)
        {
            return _indicator.Paintbar(Input, time1, time2);
        }

        /// <summary>
        /// Paints bars with a specified color for a specified time interval
        /// </summary>
        /// <returns></returns>
        public Indicator.Paintbar Paintbar(Data.IDataSeries input, string time1, string time2)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.Paintbar(input, time1, time2);
        }

        /// <summary>
        /// Volume traded during the specific time frame.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ttVol ttVol()
        {
            return _indicator.ttVol(Input);
        }

        /// <summary>
        /// Volume traded during the specific time frame.
        /// </summary>
        /// <returns></returns>
        public Indicator.ttVol ttVol(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.ttVol(input);
        }

        /// <summary>
        /// The ttVolMA (Volume Moving Average) plots a simple moving average (SMA) of volume.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.ttVolMA ttVolMA(int period)
        {
            return _indicator.ttVolMA(Input, period);
        }

        /// <summary>
        /// The ttVolMA (Volume Moving Average) plots a simple moving average (SMA) of volume.
        /// </summary>
        /// <returns></returns>
        public Indicator.ttVolMA ttVolMA(Data.IDataSeries input, int period)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.ttVolMA(input, period);
        }
    }
}
#endregion
